@@ -29,7 +29,7 @@ Usage::
     list_workflow_types_paginator: ListWorkflowTypesPaginator = client.get_paginator("list_workflow_types")
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
 """
-from mypy_boto3_swf.client import SWFClient, SWFClient as Client
+from mypy_boto3_swf.client import SWFClient as Client, SWFClient
 from mypy_boto3_swf.paginator import (
     GetWorkflowExecutionHistoryPaginator,
     ListActivityTypesPaginator,
